@@ -13,7 +13,8 @@
  * This is a lexer for the kdesud protocol.
  */
 
-class Lexer {
+class Lexer
+{
 public:
     Lexer(const QByteArray &input);
     ~Lexer();
@@ -27,12 +28,26 @@ public:
     /** Return the token's value. */
     QByteArray &lval();
 
-    enum Tokens { 
-    Tok_none, Tok_exec=256, Tok_pass, Tok_delCmd,
-    Tok_ping, Tok_str, Tok_num , Tok_stop,
-    Tok_set, Tok_get, Tok_delVar, Tok_delGroup,
-    Tok_host, Tok_prio, Tok_sched, Tok_getKeys,
-    Tok_chkGroup, Tok_delSpecialKey, Tok_exit
+    enum Tokens {
+        Tok_none,
+        Tok_exec = 256,
+        Tok_pass,
+        Tok_delCmd,
+        Tok_ping,
+        Tok_str,
+        Tok_num,
+        Tok_stop,
+        Tok_set,
+        Tok_get,
+        Tok_delVar,
+        Tok_delGroup,
+        Tok_host,
+        Tok_prio,
+        Tok_sched,
+        Tok_getKeys,
+        Tok_chkGroup,
+        Tok_delSpecialKey,
+        Tok_exit,
     };
 
 private:
